==> nipper-0.10.4.tgz: nipper-0.10.4/ScreenOS/report-debug.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void reportSOSDebug(struct nipperConfig *nipper)
{
	// Variables
	struct adminUsersSOS *userSOSPointer;
	struct authServerSOS *authServerPointer;
	struct interfaceSOS *interfaceSOSPointer;
	struct policySOS *policySOSPointer;
	struct zonePolicyRuleSOS *ruleSOSPointer;
	struct listSOS *listSOSPointer;
	struct addressSOS *addressSOSPointer;
	struct mappingSOS *mappingSOSPointer;
	struct johnPassword *johnPointer;

	// Setting info
	printf("\n\nFor some debug settings...\n");
	printf("  True or Enabled = %d\n", true);
	printf("  False or Disabled = %d\n", false);
	printf("  Unconfigured = %d\n\n", unconfigured);

	// General Info
	printf("\n%sInformation Collected\n=====================%s\n", COL_BLUE, RESET);
	printf("Hostname: %s\n", nipper->hostname);
	printf("SSH Version: %d\n", nipper->sos->sshVersion);
	printf("SSH Enabled: %d\n", nipper->sos->sshEnabled);
	printf("SSH v1 Key Gen Time: %d\n", nipper->sos->sshKeyGenTime);
	printf("SSH v2 Public Key: %s\n", nipper->sos->sshPublicKey);
	if (nipper->sos->admin != 0)
	{
		printf("Admin Settings\n");
		printf("  Admin Name: %s\n", nipper->sos->admin->name);
		printf("  Admin Password: %s\n", nipper->sos->admin->password);
		printf("  Restrict Password Length: %d\n", nipper->sos->admin->restrictLength);
		printf("  Access Attempts: %d\n", nipper->sos->admin->accessAttempts);
		printf("  Privilege: %d\n", nipper->sos->admin->privilege);
		printf("  Admin IP: %s\n", nipper->sos->admin->adminIP);
		printf("  Admin Net Mask: %s\n", nipper->sos->admin->adminNetMask);
		printf("  Console Only Access: %d\n", nipper->sos->admin->consoleOnly);
		printf("  Mail Alerts: %d\n", nipper->sos->admin->mailAlert);
		printf("  E-Mail to: %s\n", nipper->sos->admin->email);
		printf("  E-Mail(1) to: %s\n", nipper->sos->admin->email1);
		printf("  E-Mail(2) to: %s\n", nipper->sos->admin->email2);
		printf("  E-Mail Server: %s\n", nipper->sos->admin->emailServer);
		printf("  Auth Timeout: %d\n", nipper->sos->admin->authTimeout);
		printf("  Auth Server: %s\n", nipper->sos->admin->authServer);
		printf("  Format: %d\n", nipper->sos->admin->adminFormat);
		printf("  HTTP Redirect: %d\n", nipper->sos->admin->httpRedirect);
		userSOSPointer = nipper->sos->admin->users;
		while (userSOSPointer != 0)
		{
			printf("  Username: %s\n", userSOSPointer->username);
			printf("    Password: %s\n", userSOSPointer->password);
			printf("    Privilege: %d\n", userSOSPointer->privilege);
			printf("    Trustee: %d\n", userSOSPointer->trustee);
			userSOSPointer = userSOSPointer->next;
		}
	}
	authServerPointer = nipper->sos->authServer;
	while (authServerPointer != 0)
	{
		printf("Auth Server: %s\n", authServerPointer->name);
		printf("  Type: %d\n", authServerPointer->type);
		printf("  ID: %d\n", authServerPointer->id);
		printf("  Server Name: %s\n", authServerPointer->serverName);
		printf("  Backup Server 1: %s\n", authServerPointer->backup1);
		printf("  Backup Server 2: %s\n", authServerPointer->backup2);
		printf("  Timeout: %d\n", authServerPointer->timeout);
		printf("  Forced Timeout: %d\n", authServerPointer->forcedTimeout);
		printf("  Source Interface: %s\n", authServerPointer->sourceInterface);
		printf("  Radius Secret: %s\n", authServerPointer->radiusSecret);
		authServerPointer = authServerPointer->next;
	}
	interfaceSOSPointer = nipper->sos->interface;
	while (interfaceSOSPointer != 0)
	{
		printf("Interface: %s\n", interfaceSOSPointer->name);
		printf("  Enabled: %d\n", interfaceSOSPointer->enabled);
		printf("  Zone: %s\n", interfaceSOSPointer->zone);
		printf("  IP Address: %s\n", interfaceSOSPointer->ipAddress);
		printf("  Manage / Monitor\n");
		printf("    Ident-Reset: %d\n", interfaceSOSPointer->manageIdent);
		printf("    MTrace: %d\n", interfaceSOSPointer->manageMtrace);
		printf("    NS Management: %d\n", interfaceSOSPointer->manageNsmgmt);
		printf("    Ping: %d\n", interfaceSOSPointer->managePing);
		printf("    SNMP: %d\n", interfaceSOSPointer->manageSnmp);
		printf("    SSH: %d\n", interfaceSOSPointer->manageSsh);
		printf("    SSL: %d\n", interfaceSOSPointer->manageSsl);
		printf("    Telnet: %d\n", interfaceSOSPointer->manageTelnet);
		printf("    Wen: %d\n", interfaceSOSPointer->manageWeb);
		interfaceSOSPointer = interfaceSOSPointer->next;
	}
	policySOSPointer = nipper->sos->policies;
	while (policySOSPointer != 0)
	{
		printf("Policy:\n");
		printf("  From: %s\n", policySOSPointer->fromZone);
		printf("  To: %s\n", policySOSPointer->toZone);
		printf("  Global: %d\n", policySOSPointer->global);
		printf("  Name: %s\n", policySOSPointer->name);
		printf("  Rule:\n");
		ruleSOSPointer = policySOSPointer->policyRules;
		while (ruleSOSPointer != 0)
		{
			printf("    ID: %d\n", ruleSOSPointer->id);
			printf("    Permit: %d\n", ruleSOSPointer->permit);
			printf("    Disabled: %d\n", ruleSOSPointer->disabled);
			printf("    Log: %d\n", ruleSOSPointer->log);
			printf("    Source:\n");
			listSOSPointer = ruleSOSPointer->source;
			while (listSOSPointer != 0)
			{
				printf("      Address: %s\n", listSOSPointer->name);
				listSOSPointer = listSOSPointer->next;
			}
			printf("    Destination:\n");
			listSOSPointer = ruleSOSPointer->dest;
			while (listSOSPointer != 0)
			{
				printf("      Address: %s\n", listSOSPointer->name);
				listSOSPointer = listSOSPointer->next;
			}
			printf("    Service:\n");
			listSOSPointer = ruleSOSPointer->service;
			while (listSOSPointer != 0)
			{
				printf("      Name: %s\n", listSOSPointer->name);
				listSOSPointer = listSOSPointer->next;
			}
			ruleSOSPointer = ruleSOSPointer->next;
		}
		policySOSPointer = policySOSPointer->next;
	}
	addressSOSPointer = nipper->sos->nameList;
	while (addressSOSPointer != 0)
	{
		printf("Name Mappings:\n");
		printf("  Zone: %s\n", addressSOSPointer->zone);
		printf("  Mappings:\n");
		mappingSOSPointer = addressSOSPointer->mapping;
		while (mappingSOSPointer != 0)
		{
			printf("    Name: %s\n", mappingSOSPointer->name);
			printf("      Address: %s\n", mappingSOSPointer->address);
			printf("      Net Mask: %s\n", mappingSOSPointer->netMask);
			printf("      Comment: %s\n", mappingSOSPointer->comment);
			mappingSOSPointer = mappingSOSPointer->next;
		}
		addressSOSPointer = addressSOSPointer->next;
	}

	// John-the-ripper
	if (nipper->john != 0)
	{
		printf("\n%sJohn-the-ripper Output\n======================%s\n", COL_BLUE, RESET);
		johnPointer = nipper->john;
		while (johnPointer != 0)
		{
			printf("Username: %s\n", johnPointer->username);
			printf("  Password: %s\n", johnPointer->password);
			johnPointer = johnPointer->next;
		}
	}
}

==> nipper-0.10.5.tgz: nipper-0.10.5/ScreenOS/report-debug.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void reportSOSDebug(struct nipperConfig *nipper)
{
	// Variables
	struct adminUsersSOS *userSOSPointer = 0;
	struct authServerSOS *authServerPointer = 0;
	struct interfaceSOS *interfaceSOSPointer = 0;
	struct policySOS *policySOSPointer = 0;
	struct zonePolicyRuleSOS *ruleSOSPointer = 0;
	struct listSOS *listSOSPointer = 0;
	struct addressSOS *addressSOSPointer = 0;
	struct mappingSOS *mappingSOSPointer = 0;
	struct johnPassword *johnPointer = 0;

	// Setting info
	printf("\n\nFor some debug settings...\n");
	printf("  True or Enabled = %d\n", true);
	printf("  False or Disabled = %d\n", false);
	printf("  Unconfigured = %d\n\n", unconfigured);

	// General Info
	printf("\n%sInformation Collected\n=====================%s\n", COL_BLUE, RESET);
	printf("Hostname: %s\n", nipper->hostname);
	printf("SSH Version: %d\n", nipper->sos->sshVersion);
	printf("SSH Enabled: %d\n", nipper->sos->sshEnabled);
	printf("SSH v1 Key Gen Time: %d\n", nipper->sos->sshKeyGenTime);
	printf("SSH v2 Public Key: %s\n", nipper->sos->sshPublicKey);
	if (nipper->sos->admin != 0)
	{
		printf("Admin Settings\n");
		printf("  Admin Name: %s\n", nipper->sos->admin->name);
		printf("  Admin Password: %s\n", nipper->sos->admin->password);
		printf("  Restrict Password Length: %d\n", nipper->sos->admin->restrictLength);
		printf("  Access Attempts: %d\n", nipper->sos->admin->accessAttempts);
		printf("  Privilege: %d\n", nipper->sos->admin->privilege);
		printf("  Admin IP: %s\n", nipper->sos->admin->adminIP);
		printf("  Admin Net Mask: %s\n", nipper->sos->admin->adminNetMask);
		printf("  Console Only Access: %d\n", nipper->sos->admin->consoleOnly);
		printf("  Mail Alerts: %d\n", nipper->sos->admin->mailAlert);
		printf("  E-Mail to: %s\n", nipper->sos->admin->email);
		printf("  E-Mail(1) to: %s\n", nipper->sos->admin->email1);
		printf("  E-Mail(2) to: %s\n", nipper->sos->admin->email2);
		printf("  E-Mail Server: %s\n", nipper->sos->admin->emailServer);
		printf("  Auth Timeout: %d\n", nipper->sos->admin->authTimeout);
		printf("  Auth Server: %s\n", nipper->sos->admin->authServer);
		printf("  Format: %d\n", nipper->sos->admin->adminFormat);
		printf("  HTTP Redirect: %d\n", nipper->sos->admin->httpRedirect);
		userSOSPointer = nipper->sos->admin->users;
		while (userSOSPointer != 0)
		{
			printf("  Username: %s\n", userSOSPointer->username);
			printf("    Password: %s\n", userSOSPointer->password);
			printf("    Privilege: %d\n", userSOSPointer->privilege);
			printf("    Trustee: %d\n", userSOSPointer->trustee);
			userSOSPointer = userSOSPointer->next;
		}
	}
	authServerPointer = nipper->sos->authServer;
	while (authServerPointer != 0)
	{
		printf("Auth Server: %s\n", authServerPointer->name);
		printf("  Type: %d\n", authServerPointer->type);
		printf("  ID: %d\n", authServerPointer->id);
		printf("  Server Name: %s\n", authServerPointer->serverName);
		printf("  Backup Server 1: %s\n", authServerPointer->backup1);
		printf("  Backup Server 2: %s\n", authServerPointer->backup2);
		printf("  Timeout: %d\n", authServerPointer->timeout);
		printf("  Forced Timeout: %d\n", authServerPointer->forcedTimeout);
		printf("  Source Interface: %s\n", authServerPointer->sourceInterface);
		printf("  Radius Secret: %s\n", authServerPointer->radiusSecret);
		authServerPointer = authServerPointer->next;
	}
	interfaceSOSPointer = nipper->sos->interface;
	while (interfaceSOSPointer != 0)
	{
		printf("Interface: %s\n", interfaceSOSPointer->name);
		printf("  Enabled: %d\n", interfaceSOSPointer->enabled);
		printf("  Zone: %s\n", interfaceSOSPointer->zone);
		printf("  IP Address: %s\n", interfaceSOSPointer->ipAddress);
		printf("  Manage / Monitor\n");
		printf("    Ident-Reset: %d\n", interfaceSOSPointer->manageIdent);
		printf("    MTrace: %d\n", interfaceSOSPointer->manageMtrace);
		printf("    NS Management: %d\n", interfaceSOSPointer->manageNsmgmt);
		printf("    Ping: %d\n", interfaceSOSPointer->managePing);
		printf("    SNMP: %d\n", interfaceSOSPointer->manageSnmp);
		printf("    SSH: %d\n", interfaceSOSPointer->manageSsh);
		printf("    SSL: %d\n", interfaceSOSPointer->manageSsl);
		printf("    Telnet: %d\n", interfaceSOSPointer->manageTelnet);
		printf("    Wen: %d\n", interfaceSOSPointer->manageWeb);
		interfaceSOSPointer = interfaceSOSPointer->next;
	}
	policySOSPointer = nipper->sos->policies;
	while (policySOSPointer != 0)
	{
		printf("Policy:\n");
		printf("  From: %s\n", policySOSPointer->fromZone);
		printf("  To: %s\n", policySOSPointer->toZone);
		printf("  Global: %d\n", policySOSPointer->global);
		printf("  Name: %s\n", policySOSPointer->name);
		printf("  Rule:\n");
		ruleSOSPointer = policySOSPointer->policyRules;
		while (ruleSOSPointer != 0)
		{
			printf("    ID: %d\n", ruleSOSPointer->id);
			printf("    Permit: %d\n", ruleSOSPointer->permit);
			printf("    Disabled: %d\n", ruleSOSPointer->disabled);
			printf("    Log: %d\n", ruleSOSPointer->log);
			printf("    Source:\n");
			listSOSPointer = ruleSOSPointer->source;
			while (listSOSPointer != 0)
			{
				printf("      Address: %s\n", listSOSPointer->name);
				listSOSPointer = listSOSPointer->next;
			}
			printf("    Destination:\n");
			listSOSPointer = ruleSOSPointer->dest;
			while (listSOSPointer != 0)
			{
				printf("      Address: %s\n", listSOSPointer->name);
				listSOSPointer = listSOSPointer->next;
			}
			printf("    Service:\n");
			listSOSPointer = ruleSOSPointer->service;
			while (listSOSPointer != 0)
			{
				printf("      Name: %s\n", listSOSPointer->name);
				listSOSPointer = listSOSPointer->next;
			}
			ruleSOSPointer = ruleSOSPointer->next;
		}
		policySOSPointer = policySOSPointer->next;
	}
	addressSOSPointer = nipper->sos->nameList;
	while (addressSOSPointer != 0)
	{
		printf("Name Mappings:\n");
		printf("  Zone: %s\n", addressSOSPointer->zone);
		printf("  Mappings:\n");
		mappingSOSPointer = addressSOSPointer->mapping;
		while (mappingSOSPointer != 0)
		{
			printf("    Name: %s\n", mappingSOSPointer->name);
			printf("      Address: %s\n", mappingSOSPointer->address);
			printf("      Net Mask: %s\n", mappingSOSPointer->netMask);
			printf("      Comment: %s\n", mappingSOSPointer->comment);
			mappingSOSPointer = mappingSOSPointer->next;
		}
		addressSOSPointer = addressSOSPointer->next;
	}

	// John-the-ripper
	if (nipper->john != 0)
	{
		printf("\n%sJohn-the-ripper Output\n======================%s\n", COL_BLUE, RESET);
		johnPointer = nipper->john;
		while (johnPointer != 0)
		{
			printf("Username: %s\n", johnPointer->username);
			printf("  Password: %s\n", johnPointer->password);
			johnPointer = johnPointer->next;
		}
	}
}
